@@ -98,7 +98,7 @@ def read_alphavantage_stock(symbols, api_key):
 
 
 def normalize_columns(df: pd.DataFrame):
-    problematicChars = [",", ";", ":", "{", "}", "(", ")", "=", ">", "<", "."]
+    problematicChars = [",", ";", ":", "{", "}", "(", ")", "=", ">", "<", ".", "!", "?"]
     new_cols = {}
     for column in df.columns:
 
@@ -109,6 +109,11 @@ def normalize_columns(df: pd.DataFrame):
 
         columnName = columnName.replace(" ", "_")
         columnName = columnName.replace("-", "_")
+        columnName = columnName.replace("%", "perc")
+        columnName = columnName.replace("+", "plus")
+        columnName = columnName.replace("&", "and")
+        columnName = columnName.replace("cross", "cross_pass")
+        columnName = columnName.replace("authorization", "authoriz")
         columnName = columnName.strip()
 
         for p_char in problematicChars:
